@@ -4,7 +4,7 @@ import typer
 def main(
     name: str, email: str = typer.Option(..., prompt=True, confirmation_prompt=True)
 ):
-    typer.echo(f"Hello {name}, your email is {email}")
+    print(f"Hello {name}, your email is {email}")
 
 
 if __name__ == "__main__":
