@@ -7,8 +7,8 @@ def main(
         ..., prompt=True, confirmation_prompt=True, hide_input=True
     ),
 ):
-    typer.echo(f"Hello {name}. Doing something very secure with password.")
-    typer.echo(f"...just kidding, here it is, very insecure: {password}")
+    print(f"Hello {name}. Doing something very secure with password.")
+    print(f"...just kidding, here it is, very insecure: {password}")
 
 
 if __name__ == "__main__":
