@@ -8,7 +8,7 @@ app = typer.Typer()
 
 @app.command()
 def main(
-    name: Annotated[List[str], typer.Option(help="The name to say hi to.")] = ["World"]
+    name: Annotated[List[str], typer.Option(help="The name to say hi to.")] = ["World"],
 ):
     for each_name in name:
         print(f"Hello {each_name}")
