@@ -5,17 +5,17 @@ app = typer.Typer()
 
 @app.command()
 def create(item: str):
-    typer.echo(f"Creating item: {item}")
+    print(f"Creating item: {item}")
 
 
 @app.command()
 def delete(item: str):
-    typer.echo(f"Deleting item: {item}")
+    print(f"Deleting item: {item}")
 
 
 @app.command()
 def sell(item: str):
-    typer.echo(f"Selling item: {item}")
+    print(f"Selling item: {item}")
 
 
 if __name__ == "__main__":
