@@ -1,3 +1,4 @@
+import os
 import subprocess
 import sys
 
@@ -53,8 +54,8 @@ def test_delete():
 def test_script():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
+        env={**os.environ, "PYTHONIOENCODING": "utf-8"},
     )
     assert "Usage" in result.stdout
