@@ -14,7 +14,7 @@ def test_help():
     result = runner.invoke(app, ["--help"])
     assert result.exit_code == 0
     assert "Creates a single user Hiro Hamada." in result.output
-    assert "In the next version it will create 5 users more." in result.output
+    assert "In the next version it will create 5 more users." in result.output
     assert "Commands" in result.output
     assert "create" in result.output
 
@@ -28,8 +28,7 @@ def test_command():
 def test_script():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
     )
     assert "Usage" in result.stdout
