@@ -9,7 +9,7 @@ from docs_src.options_autocompletion import tutorial003_an as mod
 runner = CliRunner()
 
 
-def test_completion():
+def test_completion_zsh():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, " "],
         capture_output=True,
@@ -25,6 +25,23 @@ def test_completion():
     assert "Sebastian" in result.stdout
 
 
+def test_completion_powershell():
+    result = subprocess.run(
+        [sys.executable, "-m", "coverage", "run", mod.__file__, " "],
+        capture_output=True,
+        encoding="utf-8",
+        env={
+            **os.environ,
+            "_TUTORIAL003_AN.PY_COMPLETE": "complete_powershell",
+            "_TYPER_COMPLETE_ARGS": "tutorial003.py --name Seb",
+            "_TYPER_COMPLETE_WORD_TO_COMPLETE": "Seb",
+        },
+    )
+    assert "Camila" not in result.stdout
+    assert "Carlos" not in result.stdout
+    assert "Sebastian" in result.stdout
+
+
 def test_1():
     result = runner.invoke(mod.app, ["--name", "Camila"])
     assert result.exit_code == 0
