@@ -53,19 +53,13 @@ def test_reject():
 def test_invalid_no_accept():
     result = runner.invoke(app, ["--no-accept"])
     assert result.exit_code != 0
-    # TODO: when deprecating Click 7, remove second option
-
-    assert (
-        "No such option: --no-accept" in result.output
-        or "no such option: --no-accept" in result.output
-    )
+    assert "No such option: --no-accept" in result.output
 
 
 def test_script():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
     )
     assert "Usage" in result.stdout
