@@ -32,11 +32,7 @@ def test_invalid():
         "Invalid value for 'BIRTH:[%Y-%m-%d|%Y-%m-%dT%H:%M:%S|%Y-%m-%d %H:%M:%S]':"
         in result.stdout
     )
-    # TODO: when deprecating Click 7, remove second option
-    assert (
-        "'july-19-1989' does not match the formats" in result.output
-        or "invalid datetime format: july-19-1989. (choose from" in result.output
-    )
+    assert "'july-19-1989' does not match the formats" in result.output
     assert "%Y-%m-%d" in result.output
     assert "%Y-%m-%dT%H:%M:%S" in result.output
     assert "%Y-%m-%d %H:%M:%S" in result.output
@@ -45,8 +41,7 @@ def test_invalid():
 def test_script():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
     )
     assert "Usage" in result.stdout
