@@ -17,6 +17,7 @@ def test_help():
     assert result.exit_code == 0
     assert "--network" in result.output
     assert "[simple|conv|lstm]" in result.output
+    assert "default: simple" in result.output
 
 
 def test_main():
@@ -25,16 +26,19 @@ def test_main():
     assert "Training neural network of type: conv" in result.output
 
 
-def test_invalid():
+def test_invalid_case():
+    result = runner.invoke(app, ["--network", "CONV"])
+    assert result.exit_code != 0
+    assert "Invalid value for '--network': 'CONV' is not one of" in result.output
+    assert "simple" in result.output
+    assert "conv" in result.output
+    assert "lstm" in result.output
+
+
+def test_invalid_other():
     result = runner.invoke(app, ["--network", "capsule"])
     assert result.exit_code != 0
-    # TODO: when deprecating Click 7, remove second option
-
-    assert (
-        "Invalid value for '--network': 'capsule' is not one of" in result.output
-        or "Invalid value for '--network': invalid choice: capsule. (choose from"
-        in result.output
-    )
+    assert "Invalid value for '--network': 'capsule' is not one of" in result.output
     assert "simple" in result.output
     assert "conv" in result.output
     assert "lstm" in result.output
@@ -43,8 +47,7 @@ def test_invalid():
 def test_script():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
     )
     assert "Usage" in result.stdout
