@@ -15,7 +15,7 @@ app.command()(mod.main)
 
 def test_main(tmpdir):
     config_file = Path(tmpdir) / "config.txt"
-    if config_file.exists():  # pragma no cover
+    if config_file.exists():  # pragma: no cover
         config_file.unlink()
     result = runner.invoke(app, ["--config", f"{config_file}"])
     text = config_file.read_text()
@@ -28,8 +28,7 @@ def test_main(tmpdir):
 def test_script():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
     )
     assert "Usage" in result.stdout
