@@ -35,19 +35,13 @@ def test_params():
 def test_invalid():
     result = runner.invoke(app, ["Camila", "--age", "15.3"])
     assert result.exit_code != 0
-    # TODO: when deprecating Click 7, remove second option
-
-    assert (
-        "Invalid value for '--age': '15.3' is not a valid integer" in result.output
-        or "Invalid value for '--age': 15.3 is not a valid integer" in result.output
-    )
+    assert "Invalid value for '--age': '15.3' is not a valid integer" in result.output
 
 
 def test_script():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
     )
     assert "Usage" in result.stdout
