@@ -15,7 +15,7 @@ app.command()(mod.main)
 
 def test_not_exists(tmpdir):
     config_file = Path(tmpdir) / "config.txt"
-    if config_file.exists():  # pragma no cover
+    if config_file.exists():  # pragma: no cover
         config_file.unlink()
     result = runner.invoke(app, ["--config", f"{config_file}"])
     assert result.exit_code != 0
@@ -41,8 +41,7 @@ def test_dir():
 def test_script():
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
         encoding="utf-8",
     )
     assert "Usage" in result.stdout
